←新闻详情

Guillermo Rauch更新于 10月30日 14:36

Vercel 的 fx v0.0.15 更快更小更省内存

fx is now much faster, smaller and efficient

AI 导读

Vercel 开发者账号发布 fx v0.0.15:长会话内存占用减少 70%,二进制体积缩小 7.66%(6.66MiB → 6.15MiB),图片密集轮次处理最高快 3.3 倍,会话恢复快约 18%,并新增模型目录自动刷新和 /fork 分叉对话。Guillermo Rauch 转发称 fx 现在更快、更小、更高效。

引用

Vercel Developers

@vercel_dev

fx v0.0.15 内存更少。恢复更快。二进制更小。 - 长会话内存占用减少 70% - 二进制体积缩小 7.66%(6.15MiB ← 6.66MiB) - 图片密集轮次处理最高快 3.3 倍 - 会话恢复快约 18% - 模型目录自动刷新 - 使用 /fork 分叉对话 - libfx 中更好的图像处理与崩溃恢复 - 多项错误修复与安全改进 https://t.co/z3uxvmORfo

查看原文

fx v0.0.15 Less memory. Faster resumes. Smaller binary. - 70% less memory in long sessions - 7.66% smaller binary (6.15mib ← 6.66mib) - Image-heavy turn processing up to 3.3× faster - Session resumes about 18% faster - Automatic model catalog refresh - Fork conversations with /fork - Better image handling & crash recovery in libfx - Multiple bug fixes & security improvements https://t.co/z3uxvmORfo

查看原帖

正文 · AI 翻译

fx 现在更快、更小、更高效 在你的 iPhone Duo 上试试 https://t.co/3Z4NESzNKd https://t.co/cA3yqS1od8

来源

Guillermo Rauch